#
# spec file for package cal10n
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor plugins%{nil}
%if "%{flavor}" == "plugins"
%bcond_without plugins
%else
%bcond_with plugins
%endif
%global base_name cal10n
Version:        0.8.1.12
Release:        1.5
License:        MIT
Group:          Development/Libraries/Java
URL:            https://cal10n.qos.ch
Source0:        %{base_name}-%{version}.tar.xz
Source1:        %{base_name}-build.tar.xz
# https://github.com/qos-ch/cal10n/pull/10
Patch0:         Fix-SupportedSourceVersion-warning.patch
BuildRequires:  fdupes
BuildRequires:  xz
BuildArch:      noarch
%if %{with plugins}
Name:           %{base_name}-maven-plugins
Summary:        Compiler assisted localization library (CAL10N) maven plugins
BuildRequires:  maven-local
BuildRequires:  mvn(ch.qos.cal10n:cal10n-api)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.wagon:wagon-ssh)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
%else
Name:           %{base_name}
Summary:        Compiler assisted localization library (CAL10N)
BuildRequires:  ant
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local >= 6
%endif

%description
%if %{with plugins}
Compiler Assisted Localization, abbreviated as CAL10N (pronounced as "calion")
is a java library for writing localized (internationalized) messages.

This package contains maven plugins
%else
Compiler Assisted Localization, abbreviated as CAL10N (pronounced as "calion")
is a java library for writing localized (internationalized) messages.
Features:
    * java compiler verifies message keys used in source code
    * tooling to detect errors in message keys
    * native2ascii tool made superfluous, as you can directly encode bundles
      in the most convenient charset, per locale.
    * good performance (300 nanoseconds per key look-up)
    * automatic reloading of resource bundles upon change
%endif

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Libraries/Java

%description javadoc
API documentation for %{name}.

%prep
%setup -q -n %{base_name}-%{version} -a1
%patch -P 0 -p1

# We don't want to depend on ant, since it will be
# present when we try to use the task
%pom_change_dep :ant :::provided %{base_name}-ant-task

%pom_disable_module cal10n-site
%pom_disable_module cal10n-api
%pom_disable_module cal10n-ant-task

%pom_change_dep -r :maven-artifact-manager :maven-core

%pom_remove_plugin -r :maven-source-plugin

# bnc#759912
cat > README.SUSE <<EOF

The documentation under Creative Commons Attribution-NonCommercial-ShareAlike
2.5 License is not suitable for Linux distributors, so it has been removed.

You may find the online version at
http://cal10n.qos.ch/manual.html

EOF

%build
%if %{with plugins}
%{mvn_file} :{*} %{name}/@1

%{mvn_package} :%{base_name}-parent __noinstall

%{mvn_build} -f -- \
	-Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ) \
    -Dsource=8 -Dproject.build.sourceEncoding=ISO-8859-1
%else
mkdir -p lib
build-jar-repository -s lib ant/ant
%{ant} package javadoc
%endif

%install
%if %{with plugins}
%mvn_install
%else
install -d -m 0755 %{buildroot}%{_javadir}/%{base_name}
install -d -m 0755 %{buildroot}%{_mavenpomdir}/%{base_name}
install -d -m 0755 %{buildroot}%{_javadocdir}/%{name}
for i in api ant-task; do
  # jar
  install -m 644 %{base_name}-${i}/target/%{base_name}-${i}-*.jar \
    %{buildroot}%{_javadir}/%{base_name}/%{base_name}-${i}.jar
  # pom
  %{mvn_install_pom} %{base_name}-${i}/pom.xml %{buildroot}%{_mavenpomdir}/%{base_name}/%{base_name}-${i}.pom
  %add_maven_depmap %{base_name}/%{base_name}-${i}.pom %{base_name}/%{base_name}-${i}.jar
  # javadoc
  install -dm 0755 %{buildroot}%{_javadocdir}/%{name}/${i}
  cp -pr %{name}-${i}/target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/${i}/
done

%endif
%fdupes -s %{buildroot}%{_javadocdir}/%{name}

%files -f .mfiles
%if %{with plugins}
%files javadoc -f .mfiles-javadoc
%else
%doc README.SUSE

%files javadoc
%{_javadocdir}/%{name}
%endif

%changelog
* Thu May  2 2024 Fridrich Strba <fstrba@suse.com>
- Fetch the latest git revision: 12th commit after 0.8.1 calling
  it 0.8.1.12
- Add a multibuild flavour to build the maven plugins
- Added patch:
  * Fix-SupportedSourceVersion-warning.patch
    + fix the following: [WARNING] Supported source version
    'RELEASE_5' from annotation processor
    'ch.qos.cal10n.verifier.processor.CAL10NAnnotationProcessor'
    less than -source '1.7'
    + uncommitted change from the following pull request:
    https://github.com/qos-ch/cal10n/pull/10
* Wed May 11 2022 Fridrich Strba <fstrba@suse.com>
- Fetch sources using source service from ch.qos git
- Upgrade to the 10th commit after 0.8.1 calling it 0.8.1.10
- Redo completely the packaging including the possibility to run
  tests if --with tests is specified
- Add the cal10n-ant-task to built artifacts
- Removed patch:
  * cal10n-0.7.7-sourcetarget.patch
    + changes factored into the build system
* Thu Apr 21 2022 David Anes <david.anes@suse.com>
- Update to 0.8.1:
  * This release adds JSR-269 support. In other words, verification
    of bundles can be performed at compilation time. See the related
    documentation for more details.
  * Fix issue with Eclipse not finding existing resources. With
    release 0.8.1, Eclipse will find bundles located under
    "src/main/resources" but still fail to find bundles located
    under "src/test/resources/".
  * When reading in bundles, the verify method in MessageKeyVerifier
    now uses the locale passed as parameter instead of always
    Locale.FR. This bug was reported by Dale Wijnand who also
    provided the releavant patch.
- Update build.xml-0.7.7.tar.xz to build.xml-0.8.1.tar.xz with
  references to version 0.8.1 to build correctly versioned jar
  files.
* Thu Oct 18 2018 Fridrich Strba <fstrba@suse.com>
- Install the maven pom files in order to generate correctly the
  mvn(...) provides.
* Wed May 16 2018 fstrba@suse.com
- Modified patch:
  * cal10n-0.7.7-sourcetarget.patch
    + Build with source and target 8 to prepare for a possible
    removal of 1.6 compatibility
- Run fdupes on documentation
* Thu Sep  7 2017 fstrba@suse.com
- Added patch:
  * cal10n-0.7.7-sourcetarget.patch
  - Force java source and target levels to 1.6 in order to allow
    building with jdk9
* Thu Dec 25 2014 p.drouand@gmail.com
- Update to version 0.7.7
  + Correctly read escaped ':', '#', '!', '=' characters. The behavior
  is documented in the Properties javadocs (http://tinyurl.com/bprdgnk).
  This fixes CAL-37 (http://jira.qos.ch/browse/CAL-37)
- Update build.xml.tar.bz2, rename it to build.xml-$VERSION and
  recompress it in xz format
- Add a requirement to xz
* Mon Jul  7 2014 tchvatal@suse.com
- Depend on junit not junit4
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Fri May  4 2012 mvyskocil@suse.cz
- fix bnc#759912 - Manual for cal10n 0.7.4 uses CC-BY-SA-NC-2.5 license
* Fri Apr 27 2012 mvyskocil@suse.cz
- format spec for Factory
* Mon Dec 12 2011 dmacvicar@suse.de
- fix build.xml files to build in openSUSE 12.1 and newer.
  MANIFEST contained an absolute path in maven-build.xml
- Fix group for javadoc subpackage
- remove id generation for buildroot (used in Fedora)
* Wed Jul 27 2011 dmacvicar@suse.de
- Un-mavenize. Build with ant
